@@ -1,5 +1,5 @@
 /*
-	SPDX-FileCopyrightText: 2009-2021 Graeme Gott <graeme@gottcode.org>
+	SPDX-FileCopyrightText: 2009-2025 Graeme Gott <graeme@gottcode.org>
 
 	SPDX-License-Identifier: GPL-3.0-or-later
 */
@@ -34,13 +34,13 @@ LanguageDialog::LanguageDialog(QWidget* parent)
 	m_language = new QComboBox(this);
 	const QStringList languages = QDir("tanglet:").entryList(QDir::Dirs | QDir::NoDotAndDotDot);
 	for (const QString& language : languages) {
-		QSettings settings(QString("tanglet:%1/language.ini").arg(language), QSettings::IniFormat);
-#if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
-		settings.setIniCodec("UTF-8");
-#endif
+		const QSettings settings(QString("tanglet:%1/language.ini").arg(language), QSettings::IniFormat);
 		QString name = settings.value("Language/Name").toString();
 		if (name.isEmpty()) {
 			name = QLocale(language).nativeLanguageName();
+			if (name.isEmpty()) {
+				continue;
+			}
 		}
 		int i;
 		for (i = 0; i < m_language->count(); ++i) {
@@ -229,7 +229,7 @@ void LanguageDialog::clicked(QAbstractButton* button)
 		m_dice->clear();
 		m_words->clear();
 		m_dictionary->clear();
-		setLanguage(QLocale::system().name());
+		setLanguage(LanguageSettings().language());
 	}
 }
 
