@@ -1,5 +1,5 @@
 /*
-	SPDX-FileCopyrightText: 2010-2021 Graeme Gott <graeme@gottcode.org>
+	SPDX-FileCopyrightText: 2010-2025 Graeme Gott <graeme@gottcode.org>
 
 	SPDX-License-Identifier: GPL-3.0-or-later
 */
@@ -13,7 +13,7 @@
 //-----------------------------------------------------------------------------
 
 LanguageSettings::LanguageSettings()
-	: m_language(QLocale::system().name())
+	: m_language(QLocale().name())
 {
 	loadDefaults();
 }
@@ -34,11 +34,6 @@ LanguageSettings::LanguageSettings(const QSettings& group)
 	, m_words(group.value("Words").toString())
 	, m_dictionary(group.value("Dictionary").toString())
 {
-	if (m_language.isEmpty()) {
-		const int language = group.value("Language").toInt();
-		m_language = QLocale(QLocale::Language(language)).name().section('_', 0, 0);
-	}
-
 	loadValues();
 	loadDefaults();
 }
@@ -82,7 +77,7 @@ void LanguageSettings::loadValues()
 		m_language = settings.value("Locale").toString();
 	}
 	if (m_language.isEmpty()) {
-		m_language = QLocale::system().name();
+		m_language = QLocale().name();
 	}
 
 	if (m_dice.isEmpty()) {
