@@ -7,10 +7,6 @@
         <source>Details</source>
         <translation>Detalles</translation>
     </message>
-    <message>
-        <source>Clear</source>
-        <translation>Borrar</translation>
-    </message>
     <message>
         <source>Guess</source>
         <translation>Supongo</translation>
@@ -142,6 +138,10 @@
         <source>Discipline</source>
         <translation>Disciplina</translation>
     </message>
+    <message>
+        <source>Unlimited</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Counts down from 30 seconds and increases on correct guesses.</source>
         <translation>Cuenta atrás de 30 segundos y aumenta en aciertos.</translation>
@@ -170,6 +170,10 @@
         <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
         <translation>Cuenta atrás de 30 segundos y aumenta o disminuye en conjeturas.</translation>
     </message>
+    <message>
+        <source>Game ends when all words are found.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Generator</name>
@@ -289,33 +293,53 @@
         <translation>Las puntuaciones más altas</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Name&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Nombre&lt;/b&gt;</translation>
+        <source>Rank</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>&lt;b&gt;Score&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Puntuación&lt;/b&gt;</translation>
+        <source>Name</source>
+        <translation>Nombre</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Date&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Fecha&lt;/b&gt;</translation>
+        <source>Score</source>
+        <translation>Puntuación</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Timer&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Cronómetro&lt;/b&gt;</translation>
+        <source>Maximum</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Date</source>
+        <translation>Fecha</translation>
+    </message>
+    <message>
+        <source>Size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Congratulations!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You beat your top score!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Well done!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You have a new high score!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>N/A</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>#%1</source>
         <translation>#%1</translation>
     </message>
-    <message>
-        <source>Question</source>
-        <translation>Pregunta</translation>
-    </message>
-    <message>
-        <source>Clear high scores?</source>
-        <translation>¿Borrar puntuaciones más altas?</translation>
-    </message>
 </context>
 <context>
     <name>Window</name>
@@ -443,18 +467,10 @@
         <source>&amp;About</source>
         <translation>&amp;Acerca de</translation>
     </message>
-    <message>
-        <source>About &amp;Hspell</source>
-        <translation>Acerca de &amp;Hspell</translation>
-    </message>
     <message>
         <source>About &amp;Qt</source>
         <translation>Acerca de &amp;Qt</translation>
     </message>
-    <message>
-        <source>About &amp;SCOWL</source>
-        <translation>Acerca de &amp;SCOWL</translation>
-    </message>
     <message>
         <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
         <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
@@ -483,14 +499,6 @@
         <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
         <translation>Lista de palabras hebreas basada en &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</translation>
     </message>
-    <message>
-        <source>About Hspell</source>
-        <translation>Acerca de Hspell</translation>
-    </message>
-    <message>
-        <source>About SCOWL</source>
-        <translation>Acerca de SCOWL</translation>
-    </message>
     <message>
         <source>Import Game</source>
         <translation>Importar Juego</translation>
@@ -563,6 +571,10 @@
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Juegon con el ratón:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Selecciona una palabra:&lt;/b&gt; Click en las letras de una palabra.&lt;br&gt;&lt;b&gt;Haz una sugerencia:&lt;/b&gt; Click en la última letras seleccionada.&lt;br&gt;&lt;b&gt;Borrar letras:&lt;/b&gt; Click en una letra seleccionada previamente.&lt;br&gt;&lt;b&gt;Borrar la palabra:&lt;/b&gt; Click dos veces en la primera letra seleccionada.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Juego con el teclado:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Selecciona una palabra:&lt;/b&gt; Teclea las letras de una palabra.&lt;br&gt;&lt;b&gt;Haz una sugerencia:&lt;/b&gt; Presiona Enter.&lt;br&gt;&lt;b&gt;Borra la palabra:&lt;/b&gt; Presiona Ctrl+Backspace.&lt;/p&gt;</translation>
     </message>
+    <message>
+        <source>Ctrl+H</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>WordCounts</name>
