@@ -7,10 +7,6 @@
         <source>Details</source>
         <translation>Részletek</translation>
     </message>
-    <message>
-        <source>Clear</source>
-        <translation>Ürít</translation>
-    </message>
     <message>
         <source>Guess</source>
         <translation>Megfejt</translation>
@@ -134,6 +130,10 @@
         <source>Discipline</source>
         <translation>Fegyelem</translation>
     </message>
+    <message>
+        <source>Unlimited</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Counts down from 30 seconds and increases on correct guesses.</source>
         <translation>Visszaszámlálás 30 másodpercről és megfejtés esetén időt nyersz.</translation>
@@ -162,6 +162,10 @@
         <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
         <translation>Visszaszámlálás 30 másodpercről és helyes vagy hibás megfejtés esetén időt nyersz vagy vesztesz.</translation>
     </message>
+    <message>
+        <source>Game ends when all words are found.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Generator</name>
@@ -280,33 +284,53 @@
         <translation>Eredmények</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Name&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Név&lt;/b&gt;</translation>
+        <source>Rank</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>&lt;b&gt;Score&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Eredmény&lt;/b&gt;</translation>
+        <source>Name</source>
+        <translation>Név</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Date&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Dátum&lt;/b&gt;</translation>
+        <source>Score</source>
+        <translation>Eredmény</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Timer&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Típus&lt;/b&gt;</translation>
+        <source>Maximum</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Date</source>
+        <translation>Dátum</translation>
+    </message>
+    <message>
+        <source>Size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Congratulations!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You beat your top score!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Well done!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You have a new high score!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>N/A</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>#%1</source>
         <translation>#%1</translation>
     </message>
-    <message>
-        <source>Question</source>
-        <translation>Kérdés</translation>
-    </message>
-    <message>
-        <source>Clear high scores?</source>
-        <translation>Eredmények törlése?</translation>
-    </message>
 </context>
 <context>
     <name>Window</name>
@@ -434,18 +458,10 @@
         <source>&amp;About</source>
         <translation>&amp;Névjegy</translation>
     </message>
-    <message>
-        <source>About &amp;Hspell</source>
-        <translation>&amp;Hspell névjegye</translation>
-    </message>
     <message>
         <source>About &amp;Qt</source>
         <translation>&amp;Qt névjegye</translation>
     </message>
-    <message>
-        <source>About &amp;SCOWL</source>
-        <translation>&amp;SCOWL névjegye</translation>
-    </message>
     <message>
         <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
         <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
@@ -474,14 +490,6 @@
         <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
         <translation>Héber szó-lista fájl Nadav Har&apos;El és Dan Kenigsberg &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; listája alapján</translation>
     </message>
-    <message>
-        <source>About Hspell</source>
-        <translation>Hspell névjegye</translation>
-    </message>
-    <message>
-        <source>About SCOWL</source>
-        <translation>SCOWL névjegye</translation>
-    </message>
     <message>
         <source>Import Game</source>
         <translation>Játék betöltése</translation>
@@ -554,6 +562,10 @@
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Egérrel:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Szó kiválasztása:&lt;/b&gt; Kattints a szó betűire.&lt;br&gt;&lt;b&gt;Megfejtés:&lt;/b&gt; Kattints az utolsó kijejölt betűre.&lt;br&gt;&lt;b&gt;Betű törlése:&lt;/b&gt; Kattints a korábban kijelölt betűre.&lt;br&gt;&lt;b&gt;Szó törlése:&lt;/b&gt; Kattints kétszer az első kijelölt betűre.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Billentyűzettel:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Szó kiválasztása:&lt;/b&gt; Írd be a szó betűit.&lt;br&gt;&lt;b&gt;Megfejtés:&lt;/b&gt; Üsd le az Enter billentyűt.&lt;br&gt;&lt;b&gt;Szó törlése:&lt;/b&gt; Üsd le a Ctrl+Backspace billentyűkombinációt.&lt;/p&gt;</translation>
     </message>
+    <message>
+        <source>Ctrl+H</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>WordCounts</name>
