@@ -7,10 +7,6 @@
         <source>Details</source>
         <translation>Išsamiau</translation>
     </message>
-    <message>
-        <source>Clear</source>
-        <translation>Išvalyti</translation>
-    </message>
     <message>
         <source>Guess</source>
         <translation>Spėti</translation>
@@ -178,6 +174,14 @@
         <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
         <translation>Skaičiuoja atvirkštine tvarka 30 sekundžių, priklausomai nuo spėjimų, laikas pridedamas arba atimamas.</translation>
     </message>
+    <message>
+        <source>Unlimited</source>
+        <translation>Neribotas</translation>
+    </message>
+    <message>
+        <source>Game ends when all words are found.</source>
+        <translation>Žaidimas baigiasi, kai yra surasti visi žodžiai.</translation>
+    </message>
 </context>
 <context>
     <name>Generator</name>
@@ -298,32 +302,52 @@
         <translation>Rekordai</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Name&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Vardas&lt;/b&gt;</translation>
+        <source>Name</source>
+        <translation>Vardas</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Score&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Surinkta taškų&lt;/b&gt;</translation>
+        <source>Score</source>
+        <translation>Surinkta taškų</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Date&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Data&lt;/b&gt;</translation>
-    </message>
-    <message>
-        <source>&lt;b&gt;Timer&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Laikmatis&lt;/b&gt;</translation>
+        <source>Date</source>
+        <translation>Data</translation>
     </message>
     <message>
         <source>#%1</source>
         <translation>#%1</translation>
     </message>
     <message>
-        <source>Question</source>
-        <translation>Klausimas</translation>
+        <source>Rank</source>
+        <translation>Rangas</translation>
     </message>
     <message>
-        <source>Clear high scores?</source>
-        <translation>Išvalyti rekordus?</translation>
+        <source>Maximum</source>
+        <translation>Daugiausia</translation>
+    </message>
+    <message>
+        <source>Size</source>
+        <translation>Dydis</translation>
+    </message>
+    <message>
+        <source>Congratulations!</source>
+        <translation>Sveikiname!</translation>
+    </message>
+    <message>
+        <source>You beat your top score!</source>
+        <translation>Jūs sumušėte savo rekordą!</translation>
+    </message>
+    <message>
+        <source>Well done!</source>
+        <translation>Puikiai padirbėta!</translation>
+    </message>
+    <message>
+        <source>You have a new high score!</source>
+        <translation>Jūs pasiekėte naują rekordą!</translation>
+    </message>
+    <message>
+        <source>N/A</source>
+        <translation>Nepasiekiama</translation>
     </message>
 </context>
 <context>
@@ -452,18 +476,10 @@
         <source>&amp;About</source>
         <translation>&amp;Apie</translation>
     </message>
-    <message>
-        <source>About &amp;Hspell</source>
-        <translation>Apie &amp;Hspell</translation>
-    </message>
     <message>
         <source>About &amp;Qt</source>
         <translation>Apie &amp;Qt</translation>
     </message>
-    <message>
-        <source>About &amp;SCOWL</source>
-        <translation>Apie &amp;SCOWL</translation>
-    </message>
     <message>
         <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
         <translation>Autorių Teisės &amp;copy; 2009-%1 Graeme Gott</translation>
@@ -492,14 +508,6 @@
         <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
         <translation>Žodžių sąrašas hebrajų kalba yra paremtas &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; pagal Nadav Har&apos;El ir Dan Kenigsberg</translation>
     </message>
-    <message>
-        <source>About Hspell</source>
-        <translation>Apie Hspell</translation>
-    </message>
-    <message>
-        <source>About SCOWL</source>
-        <translation>Apie SCOWL</translation>
-    </message>
     <message>
         <source>Import Game</source>
         <translation>Importuoti žaidimą</translation>
@@ -572,6 +580,10 @@
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Žaidimas pele:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Pasirinkti žodį:&lt;/b&gt; Spustelėti ant žodžio raidžių.&lt;br&gt;&lt;b&gt;Spėti:&lt;/b&gt; Spustelėti ant paskutinės pasirinktos raidės.&lt;br&gt;&lt;b&gt;Ištrinti raides:&lt;/b&gt; Spustelėti ant anksčiau pasirinktos raidės.&lt;br&gt;&lt;b&gt;Išvalyti žodį:&lt;/b&gt; Du kartus spustelėti ant pirmos pasirinktos raidės.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Žaidimas klaviatūra:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Pasirinkti žodį:&lt;/b&gt; Rinkti žodžio raides.&lt;br&gt;&lt;b&gt;Spėti:&lt;/b&gt; Spausti įvedimo (Enter) klavišą.&lt;br&gt;&lt;b&gt;Išvalyti žodį:&lt;/b&gt; Spausti Valdymo+Naikinimo (Ctrl+Backspace) klavišą.&lt;/p&gt;</translation>
     </message>
+    <message>
+        <source>Ctrl+H</source>
+        <translation>Ctrl+H</translation>
+    </message>
 </context>
 <context>
     <name>WordCounts</name>
