@@ -1,16 +1,12 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pt_PT" sourcelanguage="en">
+<TS version="2.1" language="pt" sourcelanguage="en">
 <context>
     <name>Board</name>
     <message>
         <source>Details</source>
         <translation>Detalhes</translation>
     </message>
-    <message>
-        <source>Clear</source>
-        <translation>Limpar</translation>
-    </message>
     <message>
         <source>Guess</source>
         <translation>Dar Palpite</translation>
@@ -142,6 +138,10 @@
         <source>Discipline</source>
         <translation>Disciplina</translation>
     </message>
+    <message>
+        <source>Unlimited</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Counts down from 30 seconds and increases on correct guesses.</source>
         <translation>Conta de 30 segundos para baixo e aumenta em palpites corretos</translation>
@@ -170,6 +170,10 @@
         <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
         <translation>Conta de 30 segundos para baixo e aumenta ou diminui nos palpites.</translation>
     </message>
+    <message>
+        <source>Game ends when all words are found.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Generator</name>
@@ -289,33 +293,53 @@
         <translation>Pontuações Máximas</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Name&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Nome&lt;/b&gt;</translation>
+        <source>Rank</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>&lt;b&gt;Score&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Pontuação&lt;/b&gt;</translation>
+        <source>Name</source>
+        <translation>Nome</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Date&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Data&lt;/b&gt;</translation>
+        <source>Score</source>
+        <translation>Pontuação</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Timer&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Temporizador&lt;/b&gt;</translation>
+        <source>Maximum</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Date</source>
+        <translation>Data</translation>
+    </message>
+    <message>
+        <source>Size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Congratulations!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You beat your top score!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Well done!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You have a new high score!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>N/A</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>#%1</source>
         <translation>#%1</translation>
     </message>
-    <message>
-        <source>Question</source>
-        <translation>Questão</translation>
-    </message>
-    <message>
-        <source>Clear high scores?</source>
-        <translation>Limpar as pontuações máximas?</translation>
-    </message>
 </context>
 <context>
     <name>Window</name>
@@ -443,18 +467,10 @@
         <source>&amp;About</source>
         <translation>&amp;Sobre</translation>
     </message>
-    <message>
-        <source>About &amp;Hspell</source>
-        <translation>Sobre o &amp;Hspell</translation>
-    </message>
     <message>
         <source>About &amp;Qt</source>
         <translation>Sobre o &amp;Qt</translation>
     </message>
-    <message>
-        <source>About &amp;SCOWL</source>
-        <translation>Sobre o &amp;SCOWL</translation>
-    </message>
     <message>
         <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
         <translation>Direitos de autor &amp;copy; 2009-%1 Graeme Gott</translation>
@@ -483,14 +499,6 @@
         <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
         <translation>A lista de palavras em Hebraico é baseada em &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; por Nadav Har&apos;El e Dan Kenigsberg</translation>
     </message>
-    <message>
-        <source>About Hspell</source>
-        <translation>Sobre o Hspell</translation>
-    </message>
-    <message>
-        <source>About SCOWL</source>
-        <translation>Sobre o SCOWL</translation>
-    </message>
     <message>
         <source>Import Game</source>
         <translation>importar Jogo</translation>
@@ -563,6 +571,10 @@
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Jogar com o Rato:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Selecionar palavra:&lt;/b&gt; Clicar nas letras de uma palavra.&lt;br&gt;&lt;b&gt;Dar um palpite:&lt;/b&gt; Clicar na última letra selecionada.&lt;br&gt;&lt;b&gt;Limpar letras:&lt;/b&gt; Clicar numa letra selecionada anteriormente.&lt;br&gt;&lt;b&gt;Limpar a palavra:&lt;/b&gt; Clicar 2 vezes na primeira letra selecionada.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Jogar com o Teclado:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Selecionar palavra:&lt;/b&gt; Digitar as letras da palavra.&lt;br&gt;&lt;b&gt;Dar um palpite:&lt;/b&gt; Pressionar a tecla Enter.&lt;br&gt;&lt;b&gt;Limpar a palavra:&lt;/b&gt; Pressionar as teclas Ctrl+Apagar.&lt;/p&gt;</translation>
     </message>
+    <message>
+        <source>Ctrl+H</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>WordCounts</name>
