@@ -7,10 +7,6 @@
         <source>Details</source>
         <translation>Detalii</translation>
     </message>
-    <message>
-        <source>Clear</source>
-        <translation>Şterge</translation>
-    </message>
     <message>
         <source>Guess</source>
         <translation>Presupuneri</translation>
@@ -178,6 +174,14 @@
         <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
         <translation>Numărătoare inversă de la 30 secunde şi creşte sau scade la presupunerile corecte.</translation>
     </message>
+    <message>
+        <source>Unlimited</source>
+        <translation>Nelimitat</translation>
+    </message>
+    <message>
+        <source>Game ends when all words are found.</source>
+        <translation>Jocul se termină cînd sînt găsite toate cuvintele.</translation>
+    </message>
 </context>
 <context>
     <name>Generator</name>
@@ -298,32 +302,52 @@
         <translation>Scoruri record</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Name&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Nume&lt;/b&gt;</translation>
+        <source>Name</source>
+        <translation>Nume</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Score&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Scor&lt;/b&gt;</translation>
+        <source>Score</source>
+        <translation>Scor</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Date&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Dată&lt;/b&gt;</translation>
-    </message>
-    <message>
-        <source>&lt;b&gt;Timer&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Temporizator&lt;/b&gt;</translation>
+        <source>Date</source>
+        <translation>Data</translation>
     </message>
     <message>
         <source>#%1</source>
         <translation>#%1</translation>
     </message>
     <message>
-        <source>Question</source>
-        <translation>Întrebare</translation>
+        <source>Rank</source>
+        <translation>Rang</translation>
     </message>
     <message>
-        <source>Clear high scores?</source>
-        <translation>Şterge scoruri record?</translation>
+        <source>Maximum</source>
+        <translation>Maximum</translation>
+    </message>
+    <message>
+        <source>Size</source>
+        <translation>Mărime</translation>
+    </message>
+    <message>
+        <source>Congratulations!</source>
+        <translation>Felicitări!</translation>
+    </message>
+    <message>
+        <source>You beat your top score!</source>
+        <translation>Ţi-ai bătut cel mai bun scor!</translation>
+    </message>
+    <message>
+        <source>Well done!</source>
+        <translation>Felicitări!</translation>
+    </message>
+    <message>
+        <source>You have a new high score!</source>
+        <translation>Ai un nou scor mare!</translation>
+    </message>
+    <message>
+        <source>N/A</source>
+        <translation>Indisponibil</translation>
     </message>
 </context>
 <context>
@@ -452,18 +476,10 @@
         <source>&amp;About</source>
         <translation>&amp;Despre</translation>
     </message>
-    <message>
-        <source>About &amp;Hspell</source>
-        <translation>Despre &amp;Hspell</translation>
-    </message>
     <message>
         <source>About &amp;Qt</source>
         <translation>Despre &amp;Qt</translation>
     </message>
-    <message>
-        <source>About &amp;SCOWL</source>
-        <translation>Despre &amp;SCOWL</translation>
-    </message>
     <message>
         <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
         <translation>Toate drepturile rezervate &amp;copy; 2009-%1 Graeme Gott</translation>
@@ -492,14 +508,6 @@
         <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
         <translation>Lista cuvintelor ebraice este bazată pe &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; de Nadav Har&apos;El şi Dan Kenigsberg</translation>
     </message>
-    <message>
-        <source>About Hspell</source>
-        <translation>Despre Hspell</translation>
-    </message>
-    <message>
-        <source>About SCOWL</source>
-        <translation>Despre SCOWL</translation>
-    </message>
     <message>
         <source>Import Game</source>
         <translation>Importă joc</translation>
@@ -572,6 +580,10 @@
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Joc cu mouse-ul:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Selectaţi un cuvînt:&lt;/b&gt; Faceţi click pe literele unui cuvînt.&lt;br&gt;&lt;b&gt;Faceţi o presupunere:&lt;/b&gt; Faceţi click pe ultima literă selectată.&lt;br&gt;&lt;b&gt;Ştergeţi literele:&lt;/b&gt; Faceţi click pe o literă anterior selectată.&lt;br&gt;&lt;b&gt;Ştergeţi cuvînt:&lt;/b&gt; Faceţi clic de două ori pe prima literă selectată.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Joc cu tastatura:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Selectaţi un cuvînt:&lt;/b&gt; TTastaţi literele cuvîntului.&lt;br&gt;&lt;b&gt;Faceţi o presupunere:&lt;/b&gt; Apăsaţi Enter.&lt;br&gt;&lt;b&gt;Ştergeţi cuvîntul:&lt;/b&gt; Apăsaţi Ctrl+Backspace.&lt;/p&gt;</translation>
     </message>
+    <message>
+        <source>Ctrl+H</source>
+        <translation>Ctrl+H</translation>
+    </message>
 </context>
 <context>
     <name>WordCounts</name>
