@@ -7,10 +7,6 @@
         <source>Details</source>
         <translation>Ayrıntılar</translation>
     </message>
-    <message>
-        <source>Clear</source>
-        <translation>Temizle</translation>
-    </message>
     <message>
         <source>Guess</source>
         <translation>Tahmin</translation>
@@ -134,6 +130,10 @@
         <source>Discipline</source>
         <translation>Disiplin</translation>
     </message>
+    <message>
+        <source>Unlimited</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Counts down from 30 seconds and increases on correct guesses.</source>
         <translation>Süre 30 saniyeden başlar ve doğru cevaplar alındığında süre artar.</translation>
@@ -162,6 +162,10 @@
         <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
         <translation>Süre 30 saniyeden başlar ve tahminin doğruluğuna göre artar veya azalır.</translation>
     </message>
+    <message>
+        <source>Game ends when all words are found.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Generator</name>
@@ -280,33 +284,53 @@
         <translation>Yüksek Skorlar</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Name&lt;/b&gt;</source>
-        <translation>&lt;b&gt;İsim&lt;/b&gt;</translation>
+        <source>Rank</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>&lt;b&gt;Score&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Skor&lt;/b&gt;</translation>
+        <source>Name</source>
+        <translation>İsim</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Date&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Tarih&lt;/b&gt;</translation>
+        <source>Score</source>
+        <translation>Skor</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Timer&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Mod&lt;/b&gt;</translation>
+        <source>Maximum</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Date</source>
+        <translation>Tarih</translation>
+    </message>
+    <message>
+        <source>Size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Congratulations!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You beat your top score!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Well done!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You have a new high score!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>N/A</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>#%1</source>
         <translation>#%1</translation>
     </message>
-    <message>
-        <source>Question</source>
-        <translation>Emin Misiniz?</translation>
-    </message>
-    <message>
-        <source>Clear high scores?</source>
-        <translation>Yüksek skorları silmek istiyor musunuz?</translation>
-    </message>
 </context>
 <context>
     <name>Window</name>
@@ -434,18 +458,10 @@
         <source>&amp;About</source>
         <translation>&amp;Hakkında</translation>
     </message>
-    <message>
-        <source>About &amp;Hspell</source>
-        <translation>&amp;Hspell Hakkında</translation>
-    </message>
     <message>
         <source>About &amp;Qt</source>
         <translation>&amp;Qt Hakkında</translation>
     </message>
-    <message>
-        <source>About &amp;SCOWL</source>
-        <translation>&amp;SCOWL Hakkında</translation>
-    </message>
     <message>
         <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
         <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
@@ -474,14 +490,6 @@
         <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
         <translation>Hebrew kelime listesi Nadav Har&apos;El and Dan Kenigsberg&apos;in &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt;&apos;den temel alınmıştır</translation>
     </message>
-    <message>
-        <source>About Hspell</source>
-        <translation>Hspell Hakkında</translation>
-    </message>
-    <message>
-        <source>About SCOWL</source>
-        <translation>SCOWL Hakkında</translation>
-    </message>
     <message>
         <source>Import Game</source>
         <translation>İçe oyun aktar</translation>
@@ -554,6 +562,10 @@
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Fare İle Oynarken:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Kelime seçimi:&lt;/b&gt; Kelimenin harflerine tıklanılır.&lt;br&gt;&lt;b&gt;Tahmin yürütme:&lt;/b&gt; Son seçilen harfe tıklanılır.&lt;br&gt;&lt;b&gt;Harfleri silme:&lt;/b&gt; Önceki seçilen harfe tıklanılır.&lt;br&gt;&lt;b&gt;Kelimeyi silme:&lt;/b&gt;İlk seçilen harfe çift tıklanılır.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Klavye İle Oynarken:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Kelime seçimi:&lt;/b&gt; Kelimenin harfi girilir.&lt;br&gt;&lt;b&gt;Tahmin yürütme:&lt;/b&gt; Enter&apos;a basılır.&lt;br&gt;&lt;b&gt;Kelimeyi silme:&lt;/b&gt; Ctrl+Backspace tuşlarına basılır.&lt;/p&gt;</translation>
     </message>
+    <message>
+        <source>Ctrl+H</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>WordCounts</name>
@@ -591,11 +603,11 @@
     <name>main</name>
     <message>
         <source>Word finding game</source>
-        <translation type="unfinished"></translation>
+        <translation>Kelime bulma oyunu</translation>
     </message>
     <message>
         <source>A game file to play.</source>
-        <translation type="unfinished"></translation>
+        <translation>Oynamak için bir oyun dosyası.</translation>
     </message>
 </context>
 </TS>
